@@ -1,13 +1,17 @@
 from functools import wraps
-from .exceptions import PyCondition
+from .exceptions import PyCondition, PyConditionError
+
+from .stage import Stage
 
 class PostCondition( object ):
   def __call__( self, func ):
+    stage = Stage()
     self.name = "%s.%s" % ( func.__module__, func.__name__ )
     @wraps( func )
     def wrapper( *args, **kwargs ):
       returnValue = func( *args, **kwargs )
-      self.assertCondition( returnValue )
+      if( stage.name == "Dev" ):
+        self.assertCondition( returnValue )
       return returnValue
     wrapper._original_func = func
 
